@@ -1,5 +1,6 @@
 #' @title Is a prime number?
-#' @description Is n a prime number?
+#' @description Is n a prime number? You can see what is a
+#' prime number [there](https://en.wikipedia.org/wiki/Prime_number).
 #' @inheritParams primefactr-package
 #' @examples
 #' IsPrime(1)         # FALSE
@@ -29,18 +30,10 @@ IsPrime <- function(n) {
 #' @export
 AllPrimesUpTo <- function(n) {
   check(n)
-  if (n == 1) {
-    return(integer(0))
-  } else if (n == 2) {
-    return(2L)
-  } else if (n == 3) {
-    return(c(2L, 3L))
-  } else {
-    primes <- rep(TRUE, n)
-    primes[1] <- FALSE
-    for (i in 2:sqrt(n)) {
-      if (primes[i]) primes[seq(2*i, n, i)] <- FALSE
-    }
-    return(which(primes))
+  primes <- rep(TRUE, n)
+  primes[1] <- FALSE
+  for (i in 1:sqrt(n)) {
+    if (primes[i]) primes[seq(i^2, n, i)] <- FALSE
   }
+  which(primes)
 }
